==> openshift-model-machineconfig-5.12.1-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/KubeletConfigBuilder.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class KubeletConfigBuilder extends io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigFluentImpl<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfig,io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigBuilder>{
  public KubeletConfigBuilder() {
    this(false);
  }
  public KubeletConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new KubeletConfig(), validationEnabled);
  }
  public KubeletConfigBuilder(io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public KubeletConfigBuilder(io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new KubeletConfig(), validationEnabled);
  }
  public KubeletConfigBuilder(io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigFluent<?> fluent,io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfig instance) {
    this(fluent, instance, false);
  }
  public KubeletConfigBuilder(io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigFluent<?> fluent,io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public KubeletConfigBuilder(io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfig instance) {
    this(instance,false);
  }
  public KubeletConfigBuilder(io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfig build() {
    KubeletConfig buildable = new KubeletConfig(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    KubeletConfigBuilder that = (KubeletConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-machineconfig-6.3.1-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/KubeletConfigBuilder.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class KubeletConfigBuilder extends KubeletConfigFluentImpl<KubeletConfigBuilder> implements VisitableBuilder<KubeletConfig,KubeletConfigBuilder>{
  public KubeletConfigBuilder() {
    this(false);
  }
  public KubeletConfigBuilder(Boolean validationEnabled) {
    this(new KubeletConfig(), validationEnabled);
  }
  public KubeletConfigBuilder(KubeletConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public KubeletConfigBuilder(KubeletConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new KubeletConfig(), validationEnabled);
  }
  public KubeletConfigBuilder(KubeletConfigFluent<?> fluent,KubeletConfig instance) {
    this(fluent, instance, false);
  }
  public KubeletConfigBuilder(KubeletConfigFluent<?> fluent,KubeletConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public KubeletConfigBuilder(KubeletConfig instance) {
    this(instance,false);
  }
  public KubeletConfigBuilder(KubeletConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  KubeletConfigFluent<?> fluent;
  Boolean validationEnabled;
  public KubeletConfig build() {
    KubeletConfig buildable = new KubeletConfig(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
